@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::WSDL11;
 use vars '$VERSION';
-$VERSION = '2.16';
+$VERSION = '2.17';
 
 use base 'XML::Compile::Cache';
 
@@ -343,7 +343,12 @@ sub findDef($;$)
         or error __x"no definitions for `{class}' found", class => $class;
 
     if(defined $name)
-    {   return $group->{$name} if exists $group->{$name};
+    {   return $group->{$name} if exists $group->{$name};  # QNAME
+
+        if($name =~ m/\:/)                                 # PREFIXED
+        {   my $qname = $self->findName($name);
+            return $group->{$qname} if exists $group->{$qname};
+        }
 
         if(my $q = first { (unpack_type $_)[1] eq $name } keys %$group)
         {   return $group->{$q};
@@ -360,8 +365,9 @@ sub findDef($;$)
     return (values %$group)[0]
         if keys %$group==1;
 
-    error __x"explicit selection required: pick one {class} from {groups}"
-      , class => $class, groups => join("\n    ", '', sort keys %$group);
+    my @alts = map $self->prefixed($_), sort keys %$group;
+    error __x"explicit selection required: pick one {class} from {alts}"
+      , class => $class, alts => join("\n    ", '', @alts);
 }
 
 
